@@ -323,11 +323,7 @@ def test_bs5_field_with_buttons_css_classes():
             ),
         )
     )
-    if django.VERSION < (5, 0):
-        expected = "field_with_buttons_lt50.html"
-    else:
-        expected = "field_with_buttons.html"
-    assert parse_form(form) == parse_expected(expected)
+    assert parse_form(form) == parse_expected("field_with_buttons.html")
 
     form = SampleForm3({})
     form.helper = FormHelper()
@@ -340,13 +336,7 @@ def test_bs5_field_with_buttons_css_classes():
             ),
         )
     )
-    if django.VERSION < (5, 0):
-        expected = "field_with_buttons_failing_lt50.html"
-    elif django.VERSION < (5, 2):
-        expected = "field_with_buttons_failing_lt52.html"
-    else:
-        expected = "field_with_buttons_failing.html"
-    assert parse_form(form) == parse_expected(expected)
+    assert parse_form(form) == parse_expected("field_with_buttons_failing.html")
 
 
 def test_field_with_buttons_select():
@@ -559,11 +549,7 @@ def test_bootstrap5_form_inline():
     form.helper.field_template = "bootstrap5/layout/inline_field.html"
     form.helper.layout = Layout("email", "password1", "last_name")
     form.helper.form_class = "row row-cols-lg-auto"
-    if django.VERSION < (5, 0):
-        expected = "test_bootstrap5_form_inline_lt50.html"
-    else:
-        expected = "test_bootstrap5_form_inline.html"
-    assert parse_form(form) == parse_expected(expected)
+    assert parse_form(form) == parse_expected("test_bootstrap5_form_inline.html")
 
 
 def test_select():
@@ -617,23 +603,12 @@ def test_file_field():
     form.helper = FormHelper()
     form.helper.layout = Layout("clearable_file")
 
-    if django.VERSION < (5, 0):
-        expected = "test_clearable_file_field_failing_lt50.html"
-    elif django.VERSION < (5, 2):
-        expected = "test_clearable_file_field_failing_lt52.html"
-    else:
-        expected = "test_clearable_file_field_failing.html"
+    expected = "test_clearable_file_field_failing.html"
     assert parse_form(form) == parse_expected(expected)
 
     form.helper.layout = Layout("file_field")
 
-    if django.VERSION < (5, 0):
-        expected = "test_file_field_failing_lt50.html"
-    elif django.VERSION < (5, 2):
-        expected = "test_file_field_failing_lt52.html"
-    else:
-        expected = "test_file_field_failing.html"
-    assert parse_form(form) == parse_expected(expected)
+    assert parse_form(form) == parse_expected("test_file_field_failing.html")
 
 
 def test_row():
@@ -662,11 +637,7 @@ def test_tabular_formset_layout():
     formset = SampleFormSet()
     formset.helper = FormHelper()
     formset.helper.template = "bootstrap5/table_inline_formset.html"
-    if django.VERSION < (5, 0):
-        expected = "test_tabular_formset_layout_lt50.html"
-    else:
-        expected = "test_tabular_formset_layout.html"
-    assert parse_form(formset) == parse_expected(expected)
+    assert parse_form(formset) == parse_expected("test_tabular_formset_layout.html")
 
     SampleFormSet = formset_factory(SampleForm, extra=3)
     data = {
@@ -676,13 +647,7 @@ def test_tabular_formset_layout():
     formset = SampleFormSet(data)
     formset.helper = FormHelper()
     formset.helper.template = "bootstrap5/table_inline_formset.html"
-    if django.VERSION < (5, 0):
-        expected = "test_tabular_formset_layout_failing_lt50.html"
-    elif django.VERSION < (5, 2):
-        expected = "test_tabular_formset_layout_failing_lt52.html"
-    else:
-        expected = "test_tabular_formset_layout_failing.html"
-    assert parse_form(formset) == parse_expected(expected)
+    assert parse_form(formset) == parse_expected("test_tabular_formset_layout_failing.html")
 
 
 def test_flat_attrs_safe():
@@ -701,8 +666,4 @@ def test_help_text_no_escape():
     form = HelpTextForm()
     form.helper = FormHelper()
     form.helper.form_tag = False
-    if django.VERSION < (5, 0):
-        expected = "help_text_escape_lt50.html"
-    else:
-        expected = "help_text_escape.html"
-    assert parse_form(form) == parse_expected(expected)
+    assert parse_form(form) == parse_expected("help_text_escape.html")
