@@ -1,16 +1,16 @@
-import re
+import random
 
+import django
 import pytest
-from crispy_forms import __version__
 from crispy_forms.bootstrap import (
     Accordion,
     AccordionGroup,
     Alert,
     AppendedText,
-    Container,
     FieldWithButtons,
     FormActions,
     InlineCheckboxes,
+    InlineField,
     InlineRadios,
     Modal,
     PrependedAppendedText,
@@ -20,34 +20,52 @@ from crispy_forms.bootstrap import (
     TabHolder,
 )
 from crispy_forms.helper import FormHelper
-from crispy_forms.layout import HTML, Field, Layout, MultiWidgetField, Submit
+from crispy_forms.layout import HTML, Field, Layout, MultiField, MultiWidgetField
 from crispy_forms.utils import render_crispy_form
 from django import forms
 from django.template import Context, Template
 from django.test import override_settings
+from django.utils.translation import activate, deactivate
+from django.utils.translation import gettext as _
+
+from crispy_bootstrap5.bootstrap5 import BS5Accordion, FloatingField, Switch
 
 from .forms import (
     CheckboxesSampleForm,
     CustomCheckboxSelectMultiple,
     CustomRadioSelect,
     GroupedChoiceForm,
+    InputsForm,
     SampleForm,
     SampleFormCustomWidgets,
 )
 from .utils import parse_expected, parse_form
 
 CONVERTERS = {
-    "textinput": "textinput textInput",
+    "textinput": "inputtext textinput textInput",
     "fileinput": "fileinput fileUpload",
     "passwordinput": "textinput textInput",
 }
 
 
+def test_field_with_custom_template():
+    test_form = SampleForm()
+    test_form.helper = FormHelper()
+    test_form.helper.layout = Layout(
+        Field("email", template="custom_field_template.html")
+    )
+
+    html = render_crispy_form(test_form)
+    assert "<h1>Special custom field</h1>" in html
+
+
 def test_multiwidget_field():
-    template = Template("""
+    template = Template(
+        """
         {% load crispy_forms_tags %}
         {% crispy form %}
-    """)
+    """
+    )
 
     test_form = SampleForm()
     test_form.helper = FormHelper()
@@ -73,10 +91,12 @@ def test_multiwidget_field():
 
 
 def test_field_type_hidden():
-    template = Template("""
+    template = Template(
+        """
         {% load crispy_forms_tags %}
         {% crispy test_form %}
-    """)
+    """
+    )
 
     test_form = SampleForm()
     test_form.helper = FormHelper()
@@ -95,13 +115,51 @@ def test_field_type_hidden():
     assert html.count('class="timeinput') == 1
 
 
-def test_field_wrapper_class():
+def test_field_wrapper_class(settings):
     form = SampleForm()
     form.helper = FormHelper()
     form.helper.layout = Layout(Field("email", wrapper_class="testing"))
 
     html = render_crispy_form(form)
-    assert html.count('class="form-group testing"') == 1
+    if settings.CRISPY_TEMPLATE_PACK == "bootstrap":
+        assert html.count('class="control-group testing"') == 1
+    elif settings.CRISPY_TEMPLATE_PACK in ("bootstrap3", "bootstrap4"):
+        assert html.count('class="form-group testing"') == 1
+
+
+def test_html_with_carriage_returns(settings):
+    test_form = SampleForm()
+    test_form.helper = FormHelper()
+    test_form.helper.layout = Layout(
+        HTML(
+            """
+            if (a==b){
+                // some comment
+                a+1;
+                foo();
+            }
+        """
+        )
+    )
+    html = render_crispy_form(test_form)
+
+    if settings.CRISPY_TEMPLATE_PACK == "uni_form":
+        assert html.count("\n") == 23
+    elif settings.CRISPY_TEMPLATE_PACK == "bootstrap":
+        assert html.count("\n") == 25
+    else:
+        assert html.count("\n") == 27
+
+
+def test_i18n():
+    activate("es")
+    form = SampleForm()
+    form.helper = FormHelper()
+    form.helper.layout = Layout(HTML(_("Enter a valid value.")))
+    html = render_crispy_form(form)
+    assert "Introduzca un valor válido" in html
+
+    deactivate()
 
 
 def test_remove_labels():
@@ -117,8 +175,25 @@ def test_remove_labels():
     assert "<label" not in html
 
 
+@pytest.mark.parametrize(
+    "input,expected",
+    [
+        ("text_input", "text_input.html"),
+        ("text_area", "text_area.html"),
+        ("checkboxes", "checkboxes.html"),
+        ("radio", "radio.html"),
+        ("single_checkbox", "single_checkbox.html"),
+    ],
+)
+def test_inputs(input, expected):
+    form = InputsForm()
+    form.helper = FormHelper()
+    form.helper.layout = Layout(input)
+    assert parse_form(form) == parse_expected(expected)
+
+
 class TestBootstrapLayoutObjects:
-    def test_custom_django_widget(self, settings):
+    def test_custom_django_widget(self):
         # Make sure an inherited RadioSelect gets rendered as it
         form = SampleFormCustomWidgets()
         assert isinstance(form.fields["inline_radios"].widget, CustomRadioSelect)
@@ -126,10 +201,7 @@ class TestBootstrapLayoutObjects:
         form.helper.layout = Layout("inline_radios")
 
         html = render_crispy_form(form)
-        if settings.CRISPY_TEMPLATE_PACK == "bootstrap4":
-            assert 'class="custom-control-input"' in html
-        else:
-            assert 'class="radio"' in html
+        assert 'class="form-check-input"' in html
 
         # Make sure an inherited CheckboxSelectMultiple gets rendered as it
         assert isinstance(
@@ -137,103 +209,58 @@ class TestBootstrapLayoutObjects:
         )
         form.helper.layout = Layout("checkboxes")
         html = render_crispy_form(form)
-        if settings.CRISPY_TEMPLATE_PACK == "bootstrap4":
-            assert 'class="custom-control-input"' in html
-        else:
-            assert 'class="checkbox"' in html
+        assert 'class="form-check-input"' in html
 
     @override_settings(CRISPY_CLASS_CONVERTERS=CONVERTERS)
-    def test_prepended_appended_text(self, settings):
+    def test_prepended_appended_text(self):
         test_form = SampleForm()
         test_form.helper = FormHelper()
         test_form.helper.layout = Layout(
             PrependedAppendedText(
-                "email", "@", "gmail.com", css_class="custom-size-class", active=True
+                "email", "@<>&", "gmail.com", css_class="form-control-lg"
             ),
-            AppendedText("password1", "#", css_class="input-lg"),
-            PrependedText("password2", "$", css_class="input-sm"),
+            AppendedText("password1", "#"),
+            PrependedText("password2", "$"),
         )
-        expected = "bootstrap4/test_layout_objects/test_prepended_appended_text.html"
-        assert parse_form(test_form) == parse_expected(expected)
-
-    def test_prepended_wrapper_class(self):
-        test_form = SampleForm()
-        test_form.helper = FormHelper()
-        test_form.helper.layout = Layout(
-            PrependedAppendedText(
-                "email", "@", "gmail.com", wrapper_class="wrapper class"
-            ),
-            PrependedAppendedText("email", "@", "gmail.com"),
-        )
-        html = render_crispy_form(test_form)
-        assert html.count('<div id="div_id_email" class="form-group">') == 1
-        assert (
-            html.count('<div id="div_id_email" class="form-group wrapper class">') == 1
-        )
-
-    def test_prepended_appended_text_in_select(self):
-        test_form = SampleForm()
-        test_form.fields["select"] = forms.ChoiceField(
-            label="Select field", choices=[(1, "Choice 1"), (2, "Choice 2")]
-        )
-
-        test_form.helper = FormHelper()
-        test_form.helper.layout = Layout(
-            AppendedText("select", "USD"),
-        )
-        html = render_crispy_form(test_form)
-
-        assert html.count("custom-select") == 1
-        assert html.count("USD") == 1
-
-    def test_prepended_appended_text_input_size(self):
-        test_form = SampleForm()
-        test_form.helper = FormHelper()
-        test_form.helper.layout = Layout(
-            PrependedAppendedText(
-                "email", "@", "gmail.com", input_size="input-group-lg"
-            ),
-            AppendedText("password1", "#", input_size="input-group-sm"),
-            PrependedText("password2", "$", input_size="input-group-lg"),
-        )
-        html = render_crispy_form(test_form)
-        assert html.count('<div class="input-group input-group-lg">') == 2
-        assert html.count('<div class="input-group input-group-sm">') == 1
+        assert parse_form(test_form) == parse_expected("test_prepended_appended_text.html")
 
     def test_inline_radios(self):
-        test_form = CheckboxesSampleForm()
-        test_form.helper = FormHelper()
-        test_form.helper.layout = Layout(InlineRadios("inline_radios"))
-        html = render_crispy_form(test_form)
+        form = CheckboxesSampleForm()
+        form.helper = FormHelper()
+        form.helper.layout = Layout(InlineRadios("inline_radios"))
+        assert parse_form(form) == parse_expected("inline_radios.html")
 
-        assert html.count('custom-control-inline"') == 2
+    def test_inline_checkboxes(self):
+        form = CheckboxesSampleForm()
+        form.helper = FormHelper()
+        form.helper.layout = InlineRadios("checkboxes")
+        assert parse_form(form) == parse_expected("inline_checkboxes.html")
 
+    def test_inline_radios_failing(self):
+        form = CheckboxesSampleForm({})
+        form.helper = FormHelper()
+        form.helper.layout = Layout(InlineRadios("inline_radios"))
+        assert parse_form(form) == parse_expected("inline_radios_failing.html")
+
+    def test_inline_checkboxes_failing(self):
+        form = CheckboxesSampleForm({})
+        form.helper = FormHelper()
+        form.helper.layout = InlineRadios("checkboxes")
+        assert parse_form(form) == parse_expected("inline_checkboxes_failing.html")
+
+    @override_settings(CRISPY_CLASS_CONVERTERS=CONVERTERS)
     def test_accordion_and_accordiongroup(self):
-        test_form = SampleForm()
-        test_form.helper = FormHelper()
-        test_form.helper.layout = Layout(
+        random.seed(0)
+        form = SampleForm()
+        form.helper = FormHelper()
+        form.helper.form_tag = False
+        form.helper.layout = Layout(
             Accordion(
                 AccordionGroup("one", "first_name"),
                 AccordionGroup("two", "password1", "password2"),
             )
         )
-        html = render_crispy_form(test_form)
-
-        match = re.search('div id="(accordion-\\d+)"', html)
-        assert match
-
-        accordion_id = match.group(1)
-
-        assert html.count('<div class="card mb-2') == 2
-        assert html.count('<div class="card-header"') == 2
-
-        assert html.count('data-parent="#{}"'.format(accordion_id)) == 2
-
-        assert html.count('<div id="one"') == 1
-        assert html.count('<div id="two"') == 1
-        assert html.count('name="first_name"') == 1
-        assert html.count('name="password1"') == 1
-        assert html.count('name="password2"') == 1
+        assert parse_form(form) == parse_expected("accordion.html")
 
     def test_accordion_css_class_is_applied(self):
         classes = "one two three"
@@ -249,7 +276,9 @@ class TestBootstrapLayoutObjects:
         )
         html = render_crispy_form(test_form)
 
-        assert html.count('<div class="%s" id="super-accordion"' % classes) == 1
+        assert (
+            html.count('<div class="accordion %s" id="super-accordion"' % classes) == 1
+        )
 
     def test_accordion_group_css_class_is_applied(self):
         classes = "one two three"
@@ -264,7 +293,7 @@ class TestBootstrapLayoutObjects:
         )
         html = render_crispy_form(test_form)
 
-        assert html.count('<div class="card mb-2 %s"' % classes) == 1
+        assert html.count('<div class="accordion-item %s"' % classes) == 1
 
     def test_accordion_active_false_not_rendered(self):
         test_form = SampleForm()
@@ -281,7 +310,10 @@ class TestBootstrapLayoutObjects:
 
         accordion_class = "collapse show"
 
-        assert html.count('<div id="one" class="%s"' % accordion_class) == 1
+        assert (
+            html.count('<div id="one" class="accordion-collapse %s"' % accordion_class)
+            == 1
+        )
 
         test_form.helper.layout = Layout(
             Accordion(
@@ -291,26 +323,97 @@ class TestBootstrapLayoutObjects:
 
         # This time, it shouldn't be there at all.
         html = render_crispy_form(test_form)
-        assert html.count('<div id="one" class="%s collapse in"' % accordion_class) == 0
+        assert (
+            html.count('<div id="one" class="accordion-collapse %s"' % accordion_class)
+            == 0
+        )
+
+    @override_settings(CRISPY_CLASS_CONVERTERS=CONVERTERS)
+    def test_bs5accordion(self):
+        random.seed(0)
+        form = SampleForm()
+        form.helper = FormHelper()
+        form.helper.form_tag = False
+        form.helper.layout = Layout(
+            BS5Accordion(
+                AccordionGroup("one", "first_name"),
+                AccordionGroup("two", "password1", "password2"),
+            )
+        )
+        assert parse_form(form) == parse_expected("accordion.html")
+
+    def test_bs5accordion_active_false_not_rendered(self):
+        test_form = SampleForm()
+        test_form.helper = FormHelper()
+        test_form.helper.layout = Layout(
+            BS5Accordion(
+                AccordionGroup("one", "first_name"),
+                # there is no ``active`` kwarg here.
+            )
+        )
+
+        # The first time, there should be one of them there.
+        html = render_crispy_form(test_form)
+
+        accordion_class = "collapse show"
+
+        assert (
+            html.count('<div id="one" class="accordion-collapse %s"' % accordion_class)
+            == 1
+        )
+
+        test_form.helper.layout = Layout(
+            BS5Accordion(
+                AccordionGroup("one", "first_name", active=False),
+            )  # now ``active`` manually set as False
+        )
+
+        # This time, it shouldn't be there at all.
+        html = render_crispy_form(test_form)
+        assert (
+            html.count('<div id="one" class="accordion-collapse %s"' % accordion_class)
+            == 0
+        )
+
+    @override_settings(CRISPY_CLASS_CONVERTERS=CONVERTERS)
+    def test_bs5accordion_flush(self):
+        random.seed(0)
+        test_form = SampleForm()
+        test_form.helper = FormHelper()
+        test_form.helper.form_tag = False
+        test_form.helper.layout = Layout(
+            BS5Accordion(
+                AccordionGroup("one", "first_name"),
+                AccordionGroup("two", "password1", "password2"),
+                flush=True,
+            )
+        )
+        assert parse_form(test_form) == parse_expected("accordion_flush.html")
+
+    @override_settings(CRISPY_CLASS_CONVERTERS=CONVERTERS)
+    def test_bs5accordion_always_open(self):
+        random.seed(0)
+        test_form = SampleForm()
+        test_form.helper = FormHelper()
+        test_form.helper.form_tag = False
+        test_form.helper.layout = Layout(
+            BS5Accordion(
+                AccordionGroup("one", "first_name"),
+                AccordionGroup("two", "password1", "password2"),
+                always_open=True,
+            )
+        )
+        assert parse_form(test_form) == parse_expected("accordion_always_open.html")
 
     def test_alert(self):
         test_form = SampleForm()
         test_form.helper = FormHelper()
-        test_form.helper.layout = Layout(Alert(content="Testing..."))
-        html = render_crispy_form(test_form)
-
-        assert html.count('<div class="alert"') == 1
-        assert html.count('<button type="button" class="close"') == 1
-        assert html.count("Testing...") == 1
-
-    def test_alert_block(self):
-        test_form = SampleForm()
-        test_form.helper = FormHelper()
-        test_form.helper.layout = Layout(Alert(content="Testing...", block=True))
-        html = render_crispy_form(test_form)
-
-        assert html.count('<div class="alert alert-block"') == 1
-        assert html.count("Testing...") == 1
+        test_form.helper.form_tag = False
+        test_form.helper.layout = Layout(
+            Alert(content="Testing...", css_class="alert-primary"),
+            Alert(content="Testing...", css_class="alert-primary", dismiss=False),
+        )
+        assert parse_form(test_form) == parse_expected("alert.html")
 
     def test_tab_and_tab_holder(self):
         test_form = SampleForm()
@@ -324,12 +427,10 @@ class TestBootstrapLayoutObjects:
                     css_class="first-tab-class",
                 ),
                 Tab("two", "password1", "password2"),
-                css_class="test-tab-holder-class",
+                css_class="tab-holder-class",
             )
         )
-        assert parse_form(test_form) == parse_expected(
-            "bootstrap4/test_layout_objects/test_tab_and_tab_holder.html"
-        )
+        assert parse_form(test_form) == parse_expected("test_tab_and_tab_holder.html")
 
     def test_tab_helper_reuse(self):
         # this is a proper form, according to the docs.
@@ -377,8 +478,7 @@ class TestBootstrapLayoutObjects:
         assert 'class="first"' in html
         assert 'class="second"' in html
 
-    @override_settings(CRISPY_CLASS_CONVERTERS=CONVERTERS)
-    def test_field_with_buttons(self, settings):
+    def test_field_with_buttons(self):
         form = SampleForm()
         form.helper = FormHelper()
         form.helper.layout = Layout(
@@ -386,17 +486,26 @@ class TestBootstrapLayoutObjects:
                 Field("password1", css_class="span4"),
                 StrictButton("Go!", css_id="go-button"),
                 StrictButton("No!", css_class="extra"),
-                StrictButton(
-                    "Test <>&", type="submit", name="whatever <>&", value="something"
-                ),
+                StrictButton("Test", type="submit", name="whatever", value="something"),
                 css_class="extra",
                 autocomplete="off",
-                input_size="input-group-sm",
             )
         )
-        assert parse_form(form) == parse_expected(
-            "bootstrap4/test_layout_objects/test_field_with_buttons.html"
-        )
+        html = render_crispy_form(form)
+
+        form_group_class = "mb-3"
+
+        assert html.count('class="%s extra"' % form_group_class) == 1
+        assert html.count('autocomplete="off"') == 1
+        assert html.count('class="span4') == 1
+        assert html.count('id="go-button"') == 1
+        assert html.count("Go!") == 1
+        assert html.count("No!") == 1
+        assert html.count('class="btn"') == 2
+        assert html.count('class="btn extra"') == 1
+        assert html.count('type="submit"') == 1
+        assert html.count('name="whatever"') == 1
+        assert html.count('value="something"') == 1
 
     def test_hidden_fields(self):
         form = SampleForm()
@@ -417,18 +526,22 @@ class TestBootstrapLayoutObjects:
         assert html.count('type="hidden"') == 5
         assert html.count("<label") == 0
 
+    def test_multifield(self):
+        test_form = SampleForm()
+        test_form.helper = FormHelper()
+        test_form.helper.layout = Layout(MultiField("", "password1", "password2"))
+        assert parse_form(test_form) == parse_expected("test_multifield.html")
+
     def test_multiplecheckboxes(self):
         test_form = CheckboxesSampleForm()
         html = render_crispy_form(test_form)
-
         assert html.count("checked") == 6
 
         test_form.helper = FormHelper(test_form)
         test_form.helper[1].wrap(InlineCheckboxes, inline=True)
         html = render_crispy_form(test_form)
-
-        assert html.count('inline="True"') == 3
-        assert html.count('custom-control-inline"') == 3
+        # TODO Fix this test
+        # assert html.count('form-check-input"') == 3
 
     def test_multiple_checkboxes_unique_ids(self):
         test_form = CheckboxesSampleForm()
@@ -449,82 +562,118 @@ class TestBootstrapLayoutObjects:
             expected_str = f'id="id_{id_suffix}"'
             assert html.count(expected_str) == 1
 
+    def test_inline_field(self):
+        form = SampleForm()
+        form.helper = FormHelper()
+        form.helper.layout = Layout(
+            InlineField("first_name", wrapper_class="col-4"),
+            InlineField("is_company", wrapper_class="col-4"),
+        )
+        form.helper.form_class = "row row-cols-lg-auto align-items-center"
+        assert parse_form(form) == parse_expected("test_inline_field.html")
+
+    def test_float_field(self):
+        form = SampleForm()
+        form.helper = FormHelper()
+        form.helper.layout = Layout(
+            FloatingField("first_name"),
+        )
+        assert parse_form(form) == parse_expected("test_floating_field.html")
+
+        form = InputsForm({})
+        form.helper = FormHelper()
+        form.helper.layout = Layout(
+            FloatingField("text_area"),
+            FloatingField("select_input"),
+        )
+        assert parse_form(form) == parse_expected("test_floating_field_failing.html")
+
     def test_grouped_checkboxes_radios(self):
         form = GroupedChoiceForm()
         form.helper = FormHelper()
         form.helper.layout = Layout("checkbox_select_multiple")
-        assert parse_form(form) == parse_expected(
-            "bootstrap4/test_layout_objects/test_grouped_checkboxes.html"
-        )
+        assert parse_form(form) == parse_expected("test_grouped_checkboxes.html")
         form.helper.layout = Layout("radio")
-        assert parse_form(form) == parse_expected(
-            "bootstrap4/test_layout_objects/test_grouped_radios.html"
-        )
+        assert parse_form(form) == parse_expected("test_grouped_radios.html")
 
         form = GroupedChoiceForm({})
         form.helper = FormHelper()
         form.helper.layout = Layout("checkbox_select_multiple")
-        expected = "bootstrap4/test_layout_objects/test_grouped_checkboxes_failing.html"
-        assert parse_form(form) == parse_expected(expected)
+        assert parse_form(form) == parse_expected("test_grouped_checkboxes_failing.html")
+
         form.helper.layout = Layout("radio")
-        expected = "bootstrap4/test_layout_objects/test_grouped_radios_failing.html"
-        assert parse_form(form) == parse_expected(expected)
+        assert parse_form(form) == parse_expected("test_grouped_radios_failing.html")
 
-    def test_non_ascii_chars_in_container_name(self):
-        """
-        Test if non-ASCII characters are saved as css_id property.
-        """
-        name = "テスト"
-        test_container = Container(name, "val1", "val2")
-        assert test_container.css_id == name
-
-    def test_bs4_modal_no_kwargs(self):
+    def test_switch(self):
         form = SampleForm()
+        form["is_company"].help_text = "is_company help text"
         form.helper = FormHelper()
-        form.helper.layout = Layout(Modal(Field("first_name")))
+        form.helper.layout = Layout(Switch("is_company"))
+        assert parse_form(form) == parse_expected("test_switch.html")
 
-        print(parse_form(form))
-        assert parse_form(form) == parse_expected(
-            "bootstrap4/test_layout_objects/bootstrap_modal_no_kwargs.html"
-        )
-
-    def test_bs4_modal_with_kwargs(self):
+    def test_switch_horizontal(self):
         form = SampleForm()
+        form["is_company"].help_text = "is_company help text"
         form.helper = FormHelper()
-        form.helper.layout = Layout(
+        form.helper.label_class = "col-lg-2"
+        form.helper.field_class = "col-lg-8"
+        form.helper.form_class = "form-horizontal"
+        form.helper.layout = Layout(Switch("is_company"), "first_name")
+        assert parse_form(form) == parse_expected("test_switch_horizontal.html")
+
+    def test_modal(self):
+        test_form = SampleForm()
+        test_form.helper = FormHelper()
+        test_form.helper.form_tag = False
+        test_form.helper.layout = Layout(
             Modal(
-                Field("first_name"),
-                css_id="id_test",
-                css_class="test-class",
+                "field1",
+                css_id="modal-id-ex",
+                css_class="modal-class-ex",
                 title="This is my modal",
-                title_id="id_title_test",
-                title_class="text-center",
             )
         )
+        assert parse_form(test_form) == parse_expected("modal.html")
 
-        assert parse_form(form) == parse_expected(
-            "bootstrap4/test_layout_objects/bootstrap_modal_with_kwargs.html"
-        )
-
-    @pytest.mark.skipif(
-        __version__[0] == "1",
-        reason="#1230 is post 1.x and fixed double class attributes bug",
-    )
-    def test_FormActions(self, settings):
-        form = SampleForm()
-        form.helper = FormHelper()
-        form.helper.field_class = "field-class"
-        form.helper.layout = Layout(
+    def test_formactions(self):
+        test_form = SampleForm()
+        test_form.helper = FormHelper()
+        test_form.helper.form_tag = False
+        test_form.helper.layout = Layout(
             FormActions(
-                HTML('<span style="display: hidden;">Information Saved</span>'),
-                Submit("Save", "Save", css_class="btn-primary"),
-                css_class="custom-class",
-                css_id="css-id",
-                data="safe <>& data",
+                HTML("<b>test</b>"),
             ),
         )
 
-        template_pack = settings.CRISPY_TEMPLATE_PACK
-        assert parse_form(form) == parse_expected(
-            f"{template_pack}/test_layout_objects/test_FormActions.html"
+        assert 'class="mb-3  "' in render_crispy_form(test_form)
+
+    def test_formactions_attrs(self):
+        test_form = SampleForm()
+        test_form.helper = FormHelper()
+        test_form.helper.form_tag = False
+        test_form.helper.field_class = "field-class"
+        test_form.helper.layout = Layout(
+            FormActions(
+                HTML("<b>test</b>"),
+                css_class="formactions-test-class",
+                css_id="formactions-test-id",
+                test="formactions-test",
+            ),
         )
+
+        assert parse_form(test_form) == parse_expected("test_formactions.html")
+
+    def test_formactions_horizontal_form(self):
+        test_form = SampleForm()
+        test_form.helper = FormHelper()
+        test_form.helper.form_tag = False
+        test_form.helper.form_class = "form-horizontal"
+        test_form.helper.layout = Layout(
+            FormActions(
+                HTML("<b>test</b>"),
+                css_class="formactions-test-class",
+            ),
+        )
+
+        expected_class = 'class="mb-3 row formactions-test-class "'
+        assert expected_class in render_crispy_form(test_form)
